@@ -1,11 +1,10 @@
-package MooseX::SlurpyConstructor;
-BEGIN {
-  $MooseX::SlurpyConstructor::VERSION = '1.2';
-}
+package MooseX::SlurpyConstructor; # git description: 1.2-17-g7df5114
 
 use strict;
 use warnings;
 
+our $VERSION = '1.30';
+
 use Moose 0.94 ();
 use Moose::Exporter;
 use Moose::Util::MetaRole;
@@ -48,17 +47,19 @@ use MooseX::SlurpyConstructor::Trait::Attribute;
 
 # ABSTRACT: Make your object constructor collect all unknown attributes
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::SlurpyConstructor - Make your object constructor collect all unknown attributes
 
 =head1 VERSION
 
-version 1.2
+version 1.30
 
 =head1 SYNOPSIS
 
@@ -97,17 +98,17 @@ version 1.2
 
 =head1 DESCRIPTION
 
-Including this module within Moose-based classes, and declaring an
+Including this module within L<Moose>-based classes, and declaring an
 attribute as 'slurpy' will allow capturing of all unknown constructor
 arguments in the given attribute.
 
-As of Moose 1.9900, this module can also be used in a role, in which case the
+As of L<Moose> 1.9900, this module can also be used in a role, in which case the
 constructor of the consuming class will become slurpy.
 
 =head1 OPTIONAL RESTRICTIONS
 
-No additional options are added to your 'slurpy' attribute, so if you want to
-make it read-only, or restrict its type constraint to a HashRef of specific
+No additional options are added to your C<slurpy> attribute, so if you want to
+make it read-only, or restrict its type constraint to a C<HashRef> of specific
 types, you should state that yourself. Typical usage may include any or all of
 the options below:
 
@@ -130,42 +131,45 @@ L<Moose::Meta::Attribute::Native::Trait::Hash>.
 
 =over 4
 
-=item MooseX::StrictConstructor
+=item * L<MooseX::StrictConstructor>
 
 The opposite of this module, making constructors die on unknown arguments.
-If both of these are used together, StrictConstructor will always
+If both of these are used together, L<MooseX::StrictConstructor> will always
 take precedence.
 
-This module can also be used in migrating code from vanilla Moose to
+This module can also be used in migrating code from vanilla L<Moose> to
 using L<MooseX::StrictConstructor>.  That was one of my original motivations
 for writing it; to allow staged migration.
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-moosex-slurpyconstructor@rt.cpan.org>, or through the web
-interface at L<http://rt.cpan.org>.  The module maintainers will be notified,
-and then you'll automatically be notified of progress on your bug as changes
-are made.
-
-You can also use the normal Moose support channels - see L<Moose#GETTING_HELP>.
-
 =head1 HISTORY
 
+=for stopwords Walde
+
 This module was originally written by Mark Morgan C<< <makk384@gmail.com> >>,
 with some bugfix patches by Christian Walde.
 
-It was completely rewritten for Moose 2.0 by Karen Etheridge C<<
-<ether@cpan.org> >>, drawing heavily on MooseX::StrictConstructor.
+It was rewritten for Moose 2.0 by Karen Etheridge
+C<< <ether@cpan.org> >>, drawing heavily on L<MooseX::StrictConstructor>.
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to the folks from moose mailing list and IRC channels for
+Thanks to the folks from the Moose mailing list and IRC channels for
 helping me find my way around some of the Moose bits I didn't
 know of before writing this module.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-SlurpyConstructor>
+(or L<bug-MooseX-SlurpyConstructor@rt.cpan.org|mailto:bug-MooseX-SlurpyConstructor@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHORS
 
 =over 4
@@ -182,13 +186,9 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Karen Etheridge.
+This software is copyright (c) 2009 by Karen Etheridge.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
